==> treat-1.1.3.tgz: package/lib/module/transformCSS.js <==
import merge from 'lodash/merge';
import mapKeys from 'lodash/mapKeys';
import each from 'lodash/each';
import pick from 'lodash/pick';
import omit from 'lodash/omit';
import isEqual from 'lodash/isEqual';
import { validateSelector } from './validateSelector';
export var simplePseudos = [
    ':-moz-any-link',
    ':-moz-full-screen',
    ':-moz-placeholder',
    ':-moz-read-only',
    ':-moz-read-write',
    ':-ms-fullscreen',
    ':-ms-input-placeholder',
    ':-webkit-any-link',
    ':-webkit-full-screen',
    '::-moz-placeholder',
    '::-moz-progress-bar',
    '::-moz-range-progress',
    '::-moz-range-thumb',
    '::-moz-range-track',
    '::-moz-selection',
    '::-ms-backdrop',
    '::-ms-browse',
    '::-ms-check',
    '::-ms-clear',
    '::-ms-fill',
    '::-ms-fill-lower',
    '::-ms-fill-upper',
    '::-ms-reveal',
    '::-ms-thumb',
    '::-ms-ticks-after',
    '::-ms-ticks-before',
    '::-ms-tooltip',
    '::-ms-track',
    '::-ms-value',
    '::-webkit-backdrop',
    '::-webkit-input-placeholder',
    '::-webkit-progress-bar',
    '::-webkit-progress-inner-value',
    '::-webkit-progress-value',
    '::-webkit-slider-runnable-track',
    '::-webkit-slider-thumb',
    '::after',
    '::backdrop',
    '::before',
    '::cue',
    '::first-letter',
    '::first-line',
    '::grammar-error',
    '::placeholder',
    '::selection',
    '::spelling-error',
    ':active',
    ':after',
    ':any-link',
    ':before',
    ':blank',
    ':checked',
    ':default',
    ':defined',
    ':disabled',
    ':empty',
    ':enabled',
    ':first',
    ':first-child',
    ':first-letter',
    ':first-line',
    ':first-of-type',
    ':focus',
    ':focus-visible',
    ':focus-within',
    ':fullscreen',
    ':hover',
    ':in-range',
    ':indeterminate',
    ':invalid',
    ':last-child',
    ':last-of-type',
    ':left',
    ':link',
    ':only-child',
    ':only-of-type',
    ':optional',
    ':out-of-range',
    ':placeholder-shown',
    ':read-only',
    ':read-write',
    ':required',
    ':right',
    ':root',
    ':scope',
    ':target',
    ':valid',
    ':visited',
];
var normalizeStyles = function (className, styles) {
    var _a;
    var omitThese = simplePseudos.concat(['@media', 'selectors']);
    var pseudoStyles = mapKeys(pick(styles, simplePseudos), function (_, pseudo) { return "" + className + pseudo; });
    var selectorStyles = {};
    if (styles.selectors) {
        selectorStyles = mapKeys(styles.selectors, function (_, selector) {
            // Themed selectors can be empty if themes haven't registered yet.
            // In this case don't validate the selector
            if (selector.length > 0) {
                validateSelector(selector);
            }
            return selector.replace(RegExp('&', 'g'), className);
        });
    }
    var rawRules = omit(styles, omitThese);
    var rawStyles = Object.keys(rawRules).length > 0
        ? (_a = {},
            _a[className] = rawRules,
            _a) : {};
    var allStyles = Object.assign(rawStyles, pseudoStyles, selectorStyles);
    Object.keys(allStyles).forEach(function (ident) {
        if (allStyles[ident]['@keyframes']) {
            var _a = allStyles[ident], keyframeRef = _a["@keyframes"], animation = _a.animation;
            if (keyframeRef) {
                Object.assign(allStyles[ident], {
                    animation: animation
                        ? animation.replace('@keyframes', keyframeRef)
                        : undefined,
                    animationName: animation ? undefined : keyframeRef,
                    '@keyframes': undefined,
                });
            }
        }
    });
    return allStyles;
};
export default (function (styles) {
    var stylesheet = {};
    var responsiveStylesheet = {};
    Object.entries(styles).forEach(function (_a) {
        var className = _a[0], styles = _a[1];
        var defaultStyles = normalizeStyles(className, styles);
        var responsiveStyles = {};
        if (styles['@media']) {
            each(styles['@media'], function (mediaStyles, query) {
                var _a;
                var blockStyles = normalizeStyles(className, mediaStyles);
                if (!isEqual(defaultStyles, blockStyles)) {
                    merge(responsiveStyles, (_a = {},
                        _a["@media " + query] = blockStyles,
                        _a));
                }
            });
        }
        merge(stylesheet, defaultStyles);
        merge(responsiveStylesheet, responsiveStyles);
    });
    return Object.assign(stylesheet, responsiveStylesheet);
});

==> treat-1.5.1.tgz: package/lib/module/transformCSS.js <==
import merge from 'lodash/merge';
import mapKeys from 'lodash/mapKeys';
import each from 'lodash/each';
import pickBy from 'lodash/pickBy';
import omit from 'lodash/omit';
import isEqual from 'lodash/isEqual';
import { validateSelector } from './validateSelector';
export var simplePseudos = [
    ':-moz-any-link',
    ':-moz-full-screen',
    ':-moz-placeholder',
    ':-moz-read-only',
    ':-moz-read-write',
    ':-ms-fullscreen',
    ':-ms-input-placeholder',
    ':-webkit-any-link',
    ':-webkit-full-screen',
    '::-moz-placeholder',
    '::-moz-progress-bar',
    '::-moz-range-progress',
    '::-moz-range-thumb',
    '::-moz-range-track',
    '::-moz-selection',
    '::-ms-backdrop',
    '::-ms-browse',
    '::-ms-check',
    '::-ms-clear',
    '::-ms-fill',
    '::-ms-fill-lower',
    '::-ms-fill-upper',
    '::-ms-reveal',
    '::-ms-thumb',
    '::-ms-ticks-after',
    '::-ms-ticks-before',
    '::-ms-tooltip',
    '::-ms-track',
    '::-ms-value',
    '::-webkit-backdrop',
    '::-webkit-input-placeholder',
    '::-webkit-progress-bar',
    '::-webkit-progress-inner-value',
    '::-webkit-progress-value',
    '::-webkit-slider-runnable-track',
    '::-webkit-slider-thumb',
    '::after',
    '::backdrop',
    '::before',
    '::cue',
    '::first-letter',
    '::first-line',
    '::grammar-error',
    '::placeholder',
    '::selection',
    '::spelling-error',
    ':active',
    ':after',
    ':any-link',
    ':before',
    ':blank',
    ':checked',
    ':default',
    ':defined',
    ':disabled',
    ':empty',
    ':enabled',
    ':first',
    ':first-child',
    ':first-letter',
    ':first-line',
    ':first-of-type',
    ':focus',
    ':focus-visible',
    ':focus-within',
    ':fullscreen',
    ':hover',
    ':in-range',
    ':indeterminate',
    ':invalid',
    ':last-child',
    ':last-of-type',
    ':left',
    ':link',
    ':only-child',
    ':only-of-type',
    ':optional',
    ':out-of-range',
    ':placeholder-shown',
    ':read-only',
    ':read-write',
    ':required',
    ':right',
    ':root',
    ':scope',
    ':target',
    ':valid',
    ':visited',
];
var simplePseudoSet = new Set(simplePseudos);
var normalizeStyles = function (className, styles) {
    var _a;
    var omitThese = simplePseudos.concat(['@media', 'selectors']);
    var pseudoStyles = mapKeys(pickBy(styles, function (_, key) { return simplePseudoSet.has(key); }), function (_, pseudo) { return "" + className + pseudo; });
    var selectorStyles = {};
    if (styles.selectors) {
        selectorStyles = mapKeys(styles.selectors, function (_, selector) {
            // Themed selectors can be empty if themes haven't registered yet.
            // In this case don't validate the selector
            if (selector.length > 0) {
                validateSelector(selector);
            }
            return selector.replace(RegExp('&', 'g'), className);
        });
    }
    var rawRules = omit(styles, omitThese);
    var rawStyles = Object.keys(rawRules).length > 0
        ? (_a = {},
            _a[className] = rawRules,
            _a) : {};
    var allStyles = Object.assign(rawStyles, pseudoStyles, selectorStyles);
    Object.keys(allStyles).forEach(function (ident) {
        if (allStyles[ident]['@keyframes']) {
            var _a = allStyles[ident], keyframeRef = _a["@keyframes"], animation = _a.animation;
            if (keyframeRef) {
                Object.assign(allStyles[ident], {
                    animation: animation
                        ? animation.replace('@keyframes', keyframeRef)
                        : undefined,
                    animationName: animation ? undefined : keyframeRef,
                    '@keyframes': undefined,
                });
            }
        }
    });
    return allStyles;
};
export default (function (styles) {
    var stylesheet = {};
    var responsiveStylesheet = {};
    Object.entries(styles).forEach(function (_a) {
        var className = _a[0], styles = _a[1];
        var defaultStyles = normalizeStyles(className, styles);
        var responsiveStyles = {};
        if (styles['@media']) {
            each(styles['@media'], function (mediaStyles, query) {
                var _a;
                var blockStyles = normalizeStyles(className, mediaStyles);
                if (!isEqual(defaultStyles, blockStyles)) {
                    merge(responsiveStyles, (_a = {},
                        _a["@media " + query] = blockStyles,
                        _a));
                }
            });
        }
        merge(stylesheet, defaultStyles);
        merge(responsiveStylesheet, responsiveStyles);
    });
    return Object.assign(stylesheet, responsiveStylesheet);
});
